package cn.estsh.i3plus.core.apiservice.controller;

import cn.estsh.i3plus.core.api.iservice.busi.ISysLogExceptionService;
import cn.estsh.i3plus.core.api.iservice.busi.ISysLogSystemService;
import cn.estsh.i3plus.icloud.core.sdk.ICoreDemoCloud;
import cn.estsh.i3plus.icloud.wms.sdk.IWmsDemoCloud;
import cn.estsh.i3plus.pojo.base.bean.BaseModelBean;
import cn.estsh.i3plus.pojo.base.bean.BaseResultBean;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.bean.SysRole;
import cn.estsh.i3plus.pojo.platform.platbean.SysLogException;
import cn.estsh.i3plus.pojo.platform.platbean.SysLogSystem;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.sql.SQLException;
import java.util.Map;

@RestController
@RequestMapping("/impp")
@Api(description="异常服务测试")
public class DemoExceptionController {

    private static final Logger LOGGER = LoggerFactory.getLogger(DemoExceptionController.class);
    @GetMapping(value="/test-exception")
    @ApiOperation(value="测试异常")
    public ResultBean testException(int type) throws Exception{
        try{
            if(type == 1){
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                        .setErrorCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode())
                        .setErrorDetail("手动抛出异常")
                        .build();
            }else if(type == 2){
                throw new SQLException("测试数据库异常");
            }else {
                return ResultBean.success("操作成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
            }
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep);
        }
    }


    @Autowired
    private ISysLogExceptionService sysLogExceptionService;


    @GetMapping(value = "/query")
    @ApiOperation(value = "异常日志复杂查询，分页，排序",notes = "异常日志复杂查询，分页，排序")
    public ResultBean querySysLogExceptionByPager(SysLogException sysLogException, Pager pager){
        try {
            System.out.println("1===============");
            ListPager logExceptionList = sysLogExceptionService.querySysLogExceptionByPager(sysLogException, pager);
            System.out.println(logExceptionList.getObjectList().size());
            System.out.println("===============pager:" + pager);
            return ResultBean.success("查询成功").setListPager(logExceptionList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }


    @Autowired
    private ISysLogSystemService syslogSystemService;

    @GetMapping(value = "/query-logSystem")
    @ApiOperation(value = "异常日志复杂查询，分页，排序",notes = "异常日志复杂查询，分页，排序")
    public ResultBean querySysLogSystemByPager(SysLogSystem sysLog, Pager pager){
        try {
            System.out.println("2===============");
            ListPager logSystemList = syslogSystemService.querySysLogSystemByPager(sysLog,pager);
            System.out.println(logSystemList.getObjectList().size());
            System.out.println("===============pager:" + pager);
            return ResultBean.success("查询成功").setListPager(logSystemList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }


    @GetMapping(value = "/query-logSystemtest2")
    @ApiOperation(value = "异常日志复杂查询，分页，排序",notes = "异常日志复杂查询，分页，排序")
    public ResultBean querySysLogSystemTest(){
        try {
            Pager pager = new Pager();
            pager.setStartRow(0);
            pager.setPageSize(10);

            SysLogSystem logSystem = new SysLogSystem();

            System.out.println("2===============");
            ListPager logSystemList = syslogSystemService.querySysLogSystemByPager(logSystem,pager);
            System.out.println(logSystemList.getObjectList().size());
            System.out.println("===============pager:" + pager);
            return ResultBean.success("查询成功").setListPager(logSystemList).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            return ResultBean.fail(busExcep);
        }catch(Exception e){
            return ImppExceptionBuilder.newInstance().buildExceptionResult(e);
        }
    }
}
